Package: inteli
Title: Interval Estimation by Likelihood Method
Version: 0.2.0
Authors@R: c(
    person("Minkyu", "Kim", , "mkim@acr.kr", role = c("aut", "cre")),
    person("Kyun-Seop", "Bae", , "k@acr.kr", role = "aut",
    comment = c(ORCID = "0000-0001-7399-5879"))
    )
Description: Currently used CI method has its limitation when the test statistics are asymmetrical (chi-square test, F-test) or the model functions are non-linear. It can be overcome by using the likelihood functions for the interval estimation. 'inteli' package now supports interval estimation for the mean, variance, variance ratio, binomial distribution, Poisson distribution, odds ratio, risk difference, relative risk and their likelihood function plots. Testing functions are also provided.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 8.0.0
Imports: graphics, stats
NeedsCompilation: no
Packaged: 2026-05-24 16:17:13 UTC; mkim
Author: Minkyu Kim [aut, cre],
  Kyun-Seop Bae [aut] (ORCID: <https://orcid.org/0000-0001-7399-5879>)
Maintainer: Minkyu Kim <mkim@acr.kr>
Repository: CRAN
Date/Publication: 2026-05-24 16:30:02 UTC
Built: R 4.6.0; ; 2026-05-24 18:39:55 UTC; unix

# Generated by roxygen2: do not edit by hand

export(lib)
export(lim)
export(liod)
export(lipois)
export(lir)
export(lird)
export(lirr)
export(liv)
export(qlib)
export(qlim)
export(qlipois)
export(qliv)
importFrom(graphics,abline)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(stats,binom.test)
importFrom(stats,nlminb)
importFrom(stats,poisson.test)
importFrom(stats,qchisq)
importFrom(stats,qf)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,t.test)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(stats,var.test)

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

lird = function (exposure.O_event.O, exposure.O_TOTAL,
                 exposure.X_event.O, exposure.X_TOTAL,
                 plot = "all", conf.level = 0.95, eps = 1e-08, k)
{
  y1 <- exposure.O_event.O
  n1 <- exposure.O_TOTAL
  y2 <- exposure.X_event.O
  n2 <- exposure.X_TOTAL

  if (length(y1) != 1 | length(n1) != 1 |
      (y1 < 0) | (n1 < 0) | !is.finite(y1) | !is.finite(n1))
    stop("Check the input!")
  if (length(y2) != 1 | length(n2) != 1 |
      (y2 < 0) | (n2 < 0) | !is.finite(y2) | !is.finite(n2))
    stop("Check the input!")
  if (n1 > 1/eps | n2 > 1/eps)
    stop("Total size(s) is/are too large")

  p1 <- y1/n1
  p2 <- y2/n2
  d1 <- n1 - y1
  d2 <- n2 - y2
  RD0 <- p1 - p2

  if (p1 == 0) p1 <- eps
  if (p2 == 0) p2 <- eps
  if (p1 == 1) p1 <- 1 - eps
  if (p2 == 1) p2 <- 1 - eps

  maxLL <- y1 * log(p1) + d1 * log(1 - p1) + y2 * log(p2) + d2 * log(1 - p2)
  maxLL <- ifelse(is.finite(maxLL), maxLL, 0)

  n <- n1 + n2

  if (!missing(k)) {
    logk <- log(k)
  } else if (n == 1) {
    logk <- log(2/(1 - conf.level))
  } else {
    logk <- n/2 * log(1 + qf(conf.level, 1, n - 1)/(n - 1))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  O1 <- function(rd) {
    L3 <- n1 + n2
    L2 <- (n1 + 2 * n2) * rd - L3 - y1 - y2
    L1 <- (n2 * rd - L3 - 2 * y2) * rd + y1 + y2
    L0 <- y2 * rd * (1 - rd)
    q <- L2^3/(3 * L3)^3 - L1 * L2/(6 * L3^2) + L0/(2 * L3)
    if (!is.finite(q) | abs(q) < eps) q <- 0
    p <- sign(q) * sqrt(max(0, L2^2/(3 * L3)^2 - L1/(3 * L3)))
    a <- (pi + ifelse(p == 0, acos(0), acos(min(max(q/p^3, -1), 1))))/3
    p2t <- min(max(eps, 2 * p * cos(a) - L2/(3 * L3)), 1 - eps)
    p1t <- min(max(eps, p2t + rd), 1 - eps)
    LL <- y1 * log(p1t) + d1 * log(1 - p1t) + y2 * log(p2t) + d2 * log(1 - p2t)
    LL <- ifelse(is.finite(LL), LL, 0)
    maxLL - LL - logk
  }

  LLt <- function(rd) {
    L3 <- n1 + n2
    L2 <- (n1 + 2 * n2) * rd - L3 - y1 - y2
    L1 <- (n2 * rd - L3 - 2 * y2) * rd + y1 + y2
    L0 <- y2 * rd * (1 - rd)
    q <- L2^3/(3 * L3)^3 - L1 * L2/(6 * L3^2) + L0/(2 * L3)
    p <- sign(q) * sqrt(max(0, L2^2/(3 * L3)^2 - L1/(3 * L3)))
    a <- (pi + acos(min(max(q/p^3, -1), 1)))/3
    p2t <- 2 * p * cos(a) - L2/(3 * L3)
    p1t <- p2t + rd
    y1 * log(p1t) + d1 * log(1 - p1t) + y2 * log(p2t) + d2 * log(1 - p2t)
  }

  O1t <- function(rd) maxLL - LLt(rd) - logk
  O2t <- function(rd) LLt(rd)
  O3t <- function(rd) maxLL - LLt(rd)

  if (RD0 < -1 + eps) {
    rLL <- -1
  } else {
    rTemp <- try(uniroot(O1, c(-1 + eps, RD0 + eps)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rLL <- rTemp$root, rLL <- -1)
  }

  if (RD0 > 1 - eps) {
    rUL <- 1
  } else {
    rTemp <- try(uniroot(O1, c(RD0 - eps, 1 - eps)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rUL <- rTemp$root, rUL <- 1)
  }

  CI.se <- sqrt(p1 * (1 - p1)/n1 + p2 * (1 - p2)/n2)
  CI.low <- RD0 - qnorm(0.5 + conf.level/2) * CI.se
  CI.up <- RD0 + qnorm(0.5 + conf.level/2) * CI.se

  demo <- c("Total Counts" = n, "Conf. Level" = conf.level,
            "Cutoff Value k" = exp(logk), "maxLL" = maxLL)
  contin_2x2 <- matrix(c(y1, y2, y1 + y2,
                         d1, d2, d1 + d2,
                         n1, n2, n,
                         p1, p2, RD0), nrow = 3)
  colnames(contin_2x2) = c("Event (+)", "Event (-)", "Total", "Proportion")
  rownames(contin_2x2) = c("Exposure (+)", "Exposure (-)", "Total / Risk Diff")
  LI <- c("Point Estimate" = RD0, "lower" = rLL, "upper" = rUL, "width" = rUL - rLL)
  CI <- c("Point Estimate" = RD0, "lower" = CI.low, "upper" = CI.up, "width" = CI.up - CI.low)

  plot <- c("Current plot setting is" = plot)
  z <- list(demo = demo, contin_2x2 = contin_2x2, LI = LI, CI = CI, plot = plot)

  plot2 <- c("! Plot CANNOT be drawn :: DATA not supported")
  z2 <- list(demo = demo, contin_2x2 = contin_2x2, LI = LI, CI = CI, plot = plot2)

  if (-1 + eps < RD0 &  RD0 < 1 - eps) {
    drd <- seq(-1, 1, length.out = 1e5)
    if (plot == "all") {
      O1plot <- function(rd) {
        plot(rd, O1t(rd), type = "l",
             xlab = "Risk Difference Value",
             ylab = "maxLL - LL - logk",
             main = "Adj. Objective Function (O1 type)")
        abline(h = 0, col = "red")
        abline(v = RD0, lty=2)
        legend("topright",
               legend = c(paste("PE = ", format(RD0, digits = 2)), "Zero Line"),
               lty = c(2, 1),
               col = c("black", "red"))
      }
      O2plot <- function(rd) {
        plot(rd, O2t(rd), type = "l",
             xlab = "Risk Difference Value",
             ylab = "LL",
             main = "Adj. Log Likelihood Function (O2 type)")
        abline(h = maxLL, col = "blue")
        abline(v = RD0, lty=2)
        abline(h = maxLL - logk, col = "red")
        legend("bottomright",
               legend = c(paste("PE = ", format(RD0, digits=2)),
                          paste("maxLL = ", format(maxLL, digits=4)),
                          paste("maxLL-logk = ", format(maxLL-logk, digits=4))),
               lty = c(2, 1, 1),
               col = c("black", "blue", "red"))
      }
      O3plot <- function(rd) {
        plot(rd, O3t(rd), type = "l",
             xlab = "Risk Difference Value",
             ylab = "maxLL - LL",
             main = "Adj. Log LRT (O3 type)")
        abline(h = logk, col = "red")
        abline(v = RD0, lty = 2)
        legend("topright",
               legend = c(paste("PE = ", format(RD0, digits = 2)),
                          paste("logk = ", format(logk, digits = 4))),
               lty = c(2, 1),
               col = c("black", "red"))
      }
      par(mfrow = c(2,2))
      O1plot(drd); O2plot(drd); O3plot(drd)
      par(mfrow = c(1,1))
    } else if (plot == "OBJ" | plot == "O1" | plot == 1) {
      O1plot(drd)
    } else if (plot == "OFV" | plot == "O2" | plot == 2) {
      O2plot(drd)
    } else if (plot == "LRT" | plot == "O3" | plot == 3) {
      O3plot(drd)
    } else {}
    z
  }
  else return(z2)
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

qlim = function (set.a, set.b, conf.level = 0.95, df = 1, k)
{
  x <- set.a[!is.na(set.a)]
  y <- set.b[!is.na(set.b)]
  n1 <- length(x)
  n2 <- length(y)
  n0 <- n1 + n2

  if (!is.numeric(x) | sum(is.infinite(x) > 0) | sum(is.nan(x)) >
      0 | n1 < 3 | length(unique(x)) == 1)
    stop("Check the input!")
  if (!is.numeric(y) | sum(is.infinite(y) > 0) | sum(is.nan(y)) >
      0 | n2 < 3 | length(unique(y)) == 1)
    stop("Check the input!")

  m1 <- mean(x)
  m2 <- mean(y)
  m0 <- m1 - m2

  if (!missing(k)) {
    logk <- log(k)
  } else {
    logk <- n0/2 * log(1 + qf(conf.level, 1, n0 - df)/(n0 - df))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  LL1 <- function(th) -n1/2 * (log(2 * pi * sum((x - th)^2)/n1) + 1)
  LL2 <- function(th) -n2/2 * (log(2 * pi * sum((y - th)^2)/n2) + 1)
  maxLL1 <- sapply(m1, LL1)
  maxLL2 <- sapply(m2, LL2)
  maxLL <- sapply(m1, LL1) + sapply(m2, LL2)

  O2 <- function(d) {
    mLLt <- function(m2t) -(sapply(m2t + d, LL1) + sapply(m2t, LL2))
    m2t <- nlminb(start = m2, objective = mLLt)
    -m2t$objective
  }
  O1 <- function(d) maxLL - O2(d) - logk

  meanLL <- uniroot(O1, c(-1e4, m0))$root
  meanUL <- uniroot(O1, c(m0, 1e8))$root

  CI <- t.test(x, y, conf.level = conf.level)
  demo <- c("size a" = n1, "mean a" = m1, "size b" = n2, "mean b" = m2,
            "Conf. Level" = conf.level, "LI df" = df)
  interval <- c("LI PE (= CI PE)" = m0,
                "LI lower" = meanLL, "LI upper" = meanUL,
                "LI width" = meanUL-meanLL,
                "CI lower" = CI$conf.int[1], "CI upper" = CI$conf.int[2],
                "CI width" = CI$conf.int[2]-CI$conf.int[1])
  stat <- c("p-value" = CI$p.value, "Cutoff Value k" = exp(logk),
            "Likelihood Ratio" = exp(O2(0))/exp(maxLL),
            "HETEROsced" = ifelse (O1(0) < 0, FALSE, TRUE))
  verdict <- ifelse (O1(0) < 0, "Equal Mean :: by LI method",
                     "! INequivalent Mean :: by LI method")

  if (0 < meanLL) {
    dm <- seq(-1, meanUL + 1, length.out = 1e3)
  } else if (meanUL < 0) {
    dm <- seq(meanLL - 1, 1, length.out = 1e3)
  } else {
    dm <- seq(meanLL - 1, meanUL + 1, length.out = 1e3)
  }

  plot(dm, sapply(dm, O2), type = "l",
       xlab = "Mean Difference Value",
       ylab = "LL",
       main = "Log Likelihood Function (O2 type)")
  points(0, O2(0), col = "green4", cex = 1.5, pch = 16)
  abline(h = maxLL, col = "blue")
  abline(v = m0, lty = 3)
  abline(h = maxLL - logk, col = "red")
  abline(v = 0, col = "green4", lty = 2)
  abline(h = O2(0), col = "green4")
  legend("bottom", horiz = TRUE, cex = 0.6,
         legend = c(paste("PE = ", format(m0, digits = 2)),
                    paste("maxLL = ", format(maxLL, digits = 4)),
                    paste("Cutoff = ", format(maxLL-logk, digits = 4)),
                    paste("LL Eq Mean = ", format(O2(0), digits = 4))),
         lty = c(3, 1, 2, 1),
         col = c("black", "blue", "red", "green4"))

  return(list(demo = demo, interval = interval, stat = stat, verdict = verdict))
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

qlib = function (event, total, test.val, conf.level = 0.95, eps = 1e-08, k)
{
  y <- event
  n <- total

  if (length(y) != 1 | length(n) != 1)
    stop("Event counts should be a sinlge natural number!")
  if (any(y < 0) | any(n < 0) | any(!is.finite(y)) | any(!is.finite(n)))
    stop("Check the event counts and(or) total counts!")

  if (!missing(k)) {
    logk <- log(k)
  } else if (n == 1) {
    logk <- log(2/(1 - conf.level))
  } else {
    logk <- n/2 * log(1 + qf(conf.level, 1, n - 1)/(n - 1))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  p0 <- y/n

  if (y == 0 | y == n) {
    LE <- logk/sqrt(n)
    maxLL <- 0
  } else {
    LE <- logk * sqrt(p0 * (1 - p0))
    maxLL <- y * log(p0) + (n - y) * log(1 - p0)
  }

  O1 <- function(p) {
    LL <- ifelse(p < 1e-300 | p > 1 - 1e-300, 0, y * log(p) +
                   (n - y) * log(1 - p))
    maxLL - LL - logk
  }

  O2 <- function(p) {
    ifelse(p < 1e-300 | p > 1 - 1e-300, 0, y * log(p) + (n - y) * log(1 - p))
  }

  if (p0 < eps) {
    bLL <- 0
  } else {
    rTemp <- try(uniroot(O1, c(max(eps, p0 - LE), p0 + eps)), silent = TRUE)
    ifelse (!inherits(rTemp, "try-error"), bLL <- rTemp$root, bLL <- max(p0 - LE, 0))
  }

  if (p0 > 1 - eps) {
    bUL <- 1
  } else {
    rTemp = try(uniroot(O1, c(p0 - eps, min(p0 + LE, 1 - eps))), silent = TRUE)
    ifelse (!inherits(rTemp, "try-error"), bUL <- rTemp$root, bUL <- min(p0 + LE, 1))
  }

  CI <- binom.test(event, total, test.val, conf.level = conf.level)
  demo <- c("Event Counts" = y, "Total Counts" = n,
            "Conf. Level" = conf.level, "Testing Value" = test.val)
  interval <- c("LI PE (= CI PE)" = p0,
                "LI lower" = bLL,
                "LI upper" = bUL,
                "LI width" = bUL-bLL,
                "CI lower" = CI$conf.int[1],
                "CI upper" = CI$conf.int[2],
                "CI width" = CI$conf.int[2]-CI$conf.int[1])
  stat <- c("p-value" = CI$p.value,
            "Cutoff Value k" = exp(logk),
            "Likelihood Ratio" = exp(O2(test.val))/exp(maxLL),
            "Testing Result" = ifelse(O1(test.val) < 0, TRUE, FALSE))
  verdict <- ifelse (O1(test.val) < 0,
                     "Testing value can be explained :: by LI method",
                     "! Testing value !CANNOT! be explained :: by LI method")

  dp <- seq(0, 1, length.out = 1e3)
  plot(dp, O2(dp), type = "l",
       xlab = "Proportion Value",
       ylab = "LL",
       main = "Log Likelihood Function (O2 type)")
  points(test.val, O2(test.val), col = "green4", cex = 1.5, pch = 16)
  abline(h = maxLL, col = "blue")
  abline(v = p0, lty = 3)
  abline(h = maxLL - logk, col = "red")
  abline(v = test.val, col = "green4", lty = 2)
  abline(h = O2(test.val), col = "green4")
  legend("bottomright",
         legend = c(paste("PE = ", format(p0, digits = 2)),
                    paste("maxLL = ", format(maxLL, digits = 4)),
                    paste("Cutoff = ", format(maxLL-logk, digits = 4)),
                    paste("Testing = ", format(test.val, digits = 4)),
                    paste("LL Testing = ", format(O2(test.val), digits = 4))),
         lty = c(3, 1, 1, 2, 1),
         col = c("black", "blue", "red", "green4", "green4"))

  return(list(demo = demo, interval = interval, stat = stat, verdict = verdict))
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

lirr = function (exposure.O_event.O, exposure.O_TOTAL,
                 exposure.X_event.O, exposure.X_TOTAL,
                 conf.level = 0.95, eps = 1e-08, k)
{
  y1 <- exposure.O_event.O
  n1 <- exposure.O_TOTAL
  y2 <- exposure.X_event.O
  n2 <- exposure.X_TOTAL

  if (length(y1) > 1)
    stop("Requires sinlge strata!")
  if (any(c(y1, n1 - y1, y2, n2 - y2) < 0) | n1 * n2 == 0)
    stop("Check the input!")

  p1 <- y1/n1
  p2 <- y2/n2
  d1 <- n1 - y1
  d2 <- n2 - y2
  RR0 <- p1/p2
  n <- n1 + n2

  if (!missing(k)) {
    logk <- log(k)
  } else if (n == 1) {
    logk <- log(2/(1 - conf.level))
  } else {
    logk <- n/2 * log(1 + qf(conf.level, 1, n - 1)/(n - 1))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  LE <- 1e4 * (exp(logk)/(n1 + n2))
  p1 <- min(1 - eps, max(eps, p1))
  p2 <- min(1 - eps, max(eps, p2))

  ifelse (y1 == 0 | y1 == n1 | y2 == 0 | y2 == n2, maxLL <- 0,
          maxLL <- y1 * log(p1) + d1 * log(1 - p1) + y2 * log(p2) + d2 * log(1 - p2))

  O1 <- function(rr) {
    A <- n * rr
    B <- n1 * rr + y1 + n2 + y2 * rr
    C1 <- y1 + y2
    p2t <- min(1 - eps, max(eps, (B - sqrt(B * B - 4 * A * C1))/(2 * A)))
    p1t <- min(1 - eps, max(eps, p2t * rr))
    LL <- y1 * log(p1t) + d1 * log(1 - p1t) + y2 * log(p2t) + d2 * log(1 - p2t)
    maxLL - LL - logk
  }

  LLt <- function(rr) {
    A <- n * rr
    B <- n1 * rr + y1 + n2 + y2 * rr
    C1 <- y1 + y2
    p2t <- (B - sqrt(B * B - 4 * A * C1))/(2 * A)
    p1t <- p2t * rr
    y1 * log(p1t) + d1 * log(1 - p1t) + y2 * log(p2t) + d2 * log(1 - p2t)
  }

  O1t <- function(rr) maxLL - LLt(rr) - logk
  O2t <- function(rr) LLt(rr)
  O3t <- function(rr) maxLL - LLt(rr)

  if (y1 == 0 & y2 == 0) {
    rLL <- 0
    rUL <- Inf
  } else if (y1 == 0 & y2 > 0 & y2 < n2) {
    rLL <- 0
    rTemp <- try(uniroot(O1, c(eps, 1e9)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rUL <- rTemp$root, rUL <- 1e+09)
  } else if (y1 == 0 & y2 == n2) {
    rLL <- 0
    rTemp <- try(uniroot(O1, c(eps, 1e9)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rUL <- rTemp$root, rUL <- Inf)
  } else if (y1 > 0 & y1 < n1 & y2 == 0) {
    rTemp <- try(uniroot(O1, c(eps, 100)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rLL <- rTemp$root, rLL <- 0)
    rUL <- Inf
  } else if (y1 > 0 & y1 < n1 & y2 > 0 & y2 < n2) {
    rTemp <- try(uniroot(O1, c(eps, RR0 + eps)), silent = T)
    ifelse (!inherits(rTemp, "try-error"),  rLL <- rTemp$root, rLL <- 0)
    rTemp <- try(uniroot(O1, c(RR0 - eps, RR0 + LE)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rUL <- rTemp$root, rUL <- Inf)
  } else if (y1 > 0 & y1 < n1 & y2 == n2) {
    rTemp <- try(uniroot(O1, c(eps, RR0 + eps)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rLL <- rTemp$root, rLL <- 0)
    rTemp <- try(uniroot(O1, c(RR0 - eps, 1e9)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rUL <- rTemp$root, rUL <- Inf)
  } else if (y1 == n1 & y2 == 0) {
    rTemp <- try(uniroot(O1, c(eps, 1e9)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rLL <- 1/rTemp$root, rLL <- 0)
    rUL <- Inf
  } else if (y1 == n1 & y2 > 0 & y2 < n2) {
    rTemp <- try(uniroot(O1, c(eps, RR0 + eps)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rLL <- rTemp$root, rLL <- 0)
    rTemp = try(uniroot(O1, c(RR0 - eps, 1e9)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rUL <- rTemp$root, rUL <- Inf)
  } else if (y1 == n1 & y2 == n2) {
    rTemp <- try(uniroot(O1, c(eps, RR0 + eps)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rLL <- rTemp$root, rLL <- 0)
    rTemp <- try(uniroot(O1, c(RR0 - eps, min(1 + 1/rLL, 1e+09))), silent = T)
    ifelse (!inherits(rTemp, "try-error"), rUL <- rTemp$root, rUL <- Inf)
  }

  CI.se <- sqrt(1/y1 - 1/n1 + 1/y2 - 1/n2)
  CI.low <- RR0 / exp(qnorm(0.5 + conf.level/2) * CI.se)
  CI.up <- RR0 * exp(qnorm(0.5 + conf.level/2) * CI.se)

  demo <- c("Total Counts" = n, "Conf. Level" = conf.level,
            "Cutoff Value k" = exp(logk), "maxLL" = maxLL)
  contin_2x2 <- matrix(c(y1, y2, y1 + y2,
                         d1, d2, d1 + d2,
                         n1, n2, n,
                         p1, p2, RR0), nrow = 3)
  colnames(contin_2x2) = c("Event (+)", "Event (-)", "Total", "Proportion")
  rownames(contin_2x2) = c("Exposure (+)", "Exposure (-)",
                           "Total / Relative Risk")
  LI <- c("Point Estimate" = RR0, "lower" = rLL, "upper" = rUL, "width" = rUL - rLL)
  CI <- c("Point Estimate" = RR0, "lower" = CI.low, "upper" = CI.up, "width" = CI.up - CI.low)

  z <- list(demo = demo, contin_2x2 = contin_2x2, LI = LI, CI = CI)
  z2 <- list(demo = demo, contin_2x2 = contin_2x2, LI = LI, CI = CI)

  if (y1 < n1 & y2 < n2) {
    drr <- seq(0, rUL * 2, length.out = 1e3)
    O1plot <- function(rr) {
      plot(rr, O1t(rr), type = "l",
           xlab = "Relative Risk Value",
           ylab = "maxLL - LL - logk",
           main = "Adj. Objective Function (O1 type)")
      abline(h = 0, col = "red")
      abline(v = RR0, lty=2)
      legend("topright",
             legend = c(paste("PE = ", format(RR0, digits = 2)), "Zero Line"),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    O2plot <- function(rr) {
      plot(rr, O2t(rr), type = "l",
           xlab = "Relative Risk Value",
           ylab = "LL",
           main = "Adj. Log Likelihood Function (O2 type)")
      abline(h = maxLL, col = "blue")
      abline(v = RR0, lty=2)
      abline(h = maxLL - logk, col = "red")
      legend("bottomright",
             legend = c(paste("PE = ", format(RR0, digits=2)),
                        paste("maxLL = ", format(maxLL, digits=4)),
                        paste("maxLL-logk = ", format(maxLL-logk, digits=4))),
             lty = c(2, 1, 1),
             col = c("black", "blue", "red"))
    }
    O3plot <- function(rr) {
      plot(rr, O3t(rr), type = "l",
           xlab = "Relative Risk Value",
           ylab = "maxLL - LL",
           main = "Adj. Log LRT (O3 type)")
      abline(h = logk, col = "red")
      abline(v = RR0, lty = 2)
      legend("topright",
             legend = c(paste("PE = ", format(RR0, digits = 2)),
                        paste("logk = ", format(logk, digits = 4))),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    par(mfrow = c(2,2))
    O1plot(drr); O2plot(drr); O3plot(drr)
    par(mfrow = c(1,1))
    z
  }
  else return(z2)
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

liod = function (exposure.O_event.O, exposure.O_TOTAL,
                 exposure.X_event.O, exposure.X_TOTAL,
                 plot = "all", conf.level = 0.95, eps = 1e-08, k)
{
  y1 <- exposure.O_event.O
  n1 <- exposure.O_TOTAL
  y2 <- exposure.X_event.O
  n2 <- exposure.X_TOTAL

  if (length(y1) > 1)
    stop("Requires sinlge strata!")
  if (any(c(y1, n1 - y1, y2, n2 - y2) < 0) | n1 * n2 == 0)
    stop("Check the input!")

  p1 <- y1/n1
  p2 <- y2/n2
  d1 <- n1 - y1
  d2 <- n2 - y2
  o1 <- y1/d1
  o2 <- y2/d2

  n <- n1 + n2
  OR0 <- y1/y2 * d2/d1

  ifelse (y1 == 0 | y1 == n1 | y2 == 0 | y2 == n2, maxLL <- 0,
          maxLL <- y1 * log(p1) + d1 * log(1 - p1) + y2 * log(p2) + d2 * log(1 - p2))


  if (!missing(k)) {
    logk <- log(k)
  } else if (n == 1) {
    logk <- log(2/(1 - conf.level))
  } else {
    logk <- n/2 * log(1 + qf(conf.level, 1, n - 1)/(n - 1))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  O1 <- function(or) {
    A <- n2 * (or - 1)
    B <- n1 * or + n2 - (y1 + y2) * (or - 1)
    C1 <- -(y1 + y2)
    p2t <- (-B + sqrt(B * B - 4 * A * C1))/(2 * A)
    p1t <- p2t * or/(1 + p2t * (or - 1))
    ifelse (p1t < eps | p1t > 1 - eps | p2t < eps | p2t > 1 - eps, LL <- 0,
            LL <- y1 * log(p1t) + d1 * log(1 - p1t) + y2 * log(p2t) + d2 * log(1 - p2t))
    maxLL - LL - logk
  }

  LLt <- function(or) {
    A <- n2 * (or - 1)
    B <- n1 * or + n2 - (y1 + y2) * (or - 1)
    C1 <- -(y1 + y2)
    p2t <- (-B + sqrt(B * B - 4 * A * C1))/(2 * A)
    p1t <- p2t * or/(1 + p2t * (or - 1))
    y1 * log(p1t) + d1 * log(1 - p1t) + y2 * log(p2t) + d2 * log(1 - p2t)
  }

  O1t <- function(or) maxLL - LLt(or) - logk
  O2t <- function(or) LLt(or)
  O3t <- function(or) maxLL - LLt(or)

  if (y1 == 0 & y2 == 0) {
    oLL <- 0
    oUL <- Inf
  } else if (y1 == 0 & y2 < n2) {
    oLL <- 0
    rTemp <- try(uniroot(O1, c(eps, 1e+09)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), oUL <- rTemp$root, oUL <- Inf)
  } else if (y1 == 0 & y2 == n2) {
    oLL <- 0
    rTemp <- try(uniroot(O1, c(eps, 1e+09)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), oUL <- rTemp$root, oUL <- Inf)
  } else if (y1 < n1 & y2 == 0) {
    rTemp <- try(uniroot(O1, c(eps, 1e+09)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), oLL <- rTemp$root, oLL <- 0)
    oUL <- Inf
  } else if (y1 < n1 & y2 < n2) {
    rTemp <- try(uniroot(O1, c(1e-04, OR0)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), oLL <- rTemp$root, oLL <- 0)
    rTemp <- try(uniroot(O1, c(OR0, 10000)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), oUL <- rTemp$root, oUL <- Inf)
  } else if (y1 < n1 & y2 == n2) {
    oLL <- 0
    rTemp <- try(uniroot(O1, c(eps, 1e+09)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), oUL <- rTemp$root, oUL <- Inf)
  } else if (y1 == n1 & y2 == 0) {
    rTemp <- try(uniroot(O1, c(eps, 1e+09)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), oLL <- rTemp$root, oLL <- 0)
    oUL <- Inf
  } else if (y1 == n1 & y2 < n2) {
    rTemp <- try(uniroot(O1, c(eps, 1e+09)), silent = T)
    ifelse (!inherits(rTemp, "try-error"), oLL <- rTemp$root, oLL <- 0)
    oUL <- Inf
  } else if (y1 == n1 & y2 == n2) {
    oLL <- 0
    oUL <- Inf
  }

  CI.se <- sqrt(1/y1 + 1/y2 + 1/d1 + 1/d2)
  CI.low <- OR0 / exp(qnorm(0.5 + conf.level/2) * CI.se)
  CI.up <- OR0 * exp(qnorm(0.5 + conf.level/2) * CI.se)
  demo <- c("Total Counts" = n, "Conf. Level" = conf.level,
            "Cutoff Value k" = exp(logk), "maxLL" = maxLL)
  contin_2x2 <- matrix(c(y1, y2, y1 + y2,
                         d1, d2, d1 + d2,
                         n1, n2, n,
                         y1/d1, y2/d2, OR0), nrow = 3)
  colnames(contin_2x2) = c("Event (+)", "Event (-)", "Total", "Odds")
  rownames(contin_2x2) = c("Exposure (+)", "Exposure (-)", "Total / Odds Ratio")
  LI <- c("Point Estimate" = OR0, "lower" = oLL, "upper" = oUL, "width" = oUL - oLL)
  CI <- c("Point Estimate" = OR0, "lower" = CI.low, "upper" = CI.up, "width" = CI.up - CI.low)

  plot <- c("Current plot setting is" = plot)
  z <- list(demo = demo, contin_2x2 = contin_2x2, LI = LI, CI = CI, plot = plot)

  plot2 <- c("! Plot CANNOT be drawn :: DATA not supported")
  z2 <- list(demo = demo, contin_2x2 = contin_2x2, LI = LI, CI = CI, plot = plot2)

  if (y1 < n1 & y2 < n2) {
    dor <- seq(0, 2 * oUL, length.out = 1e5)
    if (plot == "all") {
      O1plot <- function(or) {
        plot(or, O1t(or), type = "l",
             xlab = "Odds Ratio Value",
             ylab = "maxLL - LL - logk",
             main = "Adj. Objective Function (O1 type)")
        abline(h = 0, col = "red")
        abline(v = OR0, lty=2)
        legend("topright",
               legend = c(paste("PE = ", format(OR0, digits = 2)), "Zero Line"),
               lty = c(2, 1),
               col = c("black", "red"))
      }
      O2plot <- function(or) {
        plot(or, O2t(or), type = "l",
             xlab = "Odds Ratio Value",
             ylab = "LL",
             main = "Adj. Log Likelihood Function (O2 type)")
        abline(h = maxLL, col = "blue")
        abline(v = OR0, lty=2)
        abline(h = maxLL - logk, col = "red")
        legend("bottomright",
               legend = c(paste("PE = ", format(OR0, digits=2)),
                          paste("maxLL = ", format(maxLL, digits=4)),
                          paste("maxLL-logk = ", format(maxLL-logk, digits=4))),
               lty = c(2, 1, 1),
               col = c("black", "blue", "red"))
      }
      O3plot <- function(or) {
        plot(or, O3t(or), type = "l",
             xlab = "Odds Ratio Value",
             ylab = "maxLL - LL",
             main = "Adj. Log LRT (O3 type)")
        abline(h = logk, col = "red")
        abline(v = OR0, lty = 2)
        legend("topright",
               legend = c(paste("PE = ", format(OR0, digits = 2)),
                          paste("logk = ", format(logk, digits = 4))),
               lty = c(2, 1),
               col = c("black", "red"))
      }
      par(mfrow = c(2,2))
      O1plot(dor); O2plot(dor); O3plot(dor)
      par(mfrow = c(1,1))
    } else if (plot == "OBJ" | plot == "O1" | plot == 1) {
      O1plot(dor)
    } else if (plot == "OFV" | plot == "O2" | plot == 2) {
      O2plot(dor)
    } else if (plot == "LRT" | plot == "O3" | plot == 3) {
      O3plot(dor)
    } else {}
    z
  }
  else return(z2)
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

liv = function (data, plot = "all", conf.level = 0.95, df = 1.2, k)
{
  x <- data[!is.na(data)]
  n0 <- length(x)

  if (!is.numeric(x) | sum(is.infinite(x) > 0) | sum(is.nan(x)) >
      0 | n0 < 3 | length(unique(x)) == 1)
    stop("Check the input!")

  n0v0 <- sum((x - mean(x))^2)
  v0 <- n0v0 / n0
  v0c <- n0v0 / (n0 - 1)

  if (!missing(k)) {
    logk <- log(k)
    } else {
      logk <- n0/2 * log(1 + qf(conf.level, 1, n0 - df)/(n0 - df))
      logk <- min(logk, log(2/(1 - conf.level)))
    }

  O2 <- function(th) -(n0 * log(2 * pi * th) + n0v0/th)/2
  maxLL <- O2(v0)
  O1 <- function(th) maxLL - O2(th) - logk
  O3 <- function(th) maxLL - O2(th)

  varLL <- uniroot(O1, c(1e-08, v0))$root
  varUL <- uniroot(O1, c(v0, 1e+06))$root

  varLB <- n0v0 / qchisq(0.5 + conf.level/2, n0 - 1)
  varUB <- n0v0 / qchisq(0.5 - conf.level/2, n0 - 1)

  demo <- c("Sample Size" = n0, "Cutoff Value k" = exp(logk), "maxLL" = maxLL)
  LI <- c("Point Estimate" = v0, "lower" = varLL, "upper" = varUL,
          "width" = varUL - varLL)
  LI.sd <- c("Point Estimate" = sqrt(v0), "lower" = sqrt(varLL),
             "upper" = sqrt(varUL))
  CI <- c("Point Estimate" = v0c, "lower" = varLB, "upper" = varUB,
          "width" = varUB - varLB)
  plot <- c("Current plot setting is" = plot)

  dth <- seq(varLL/2, varUL * 2, length.out = 1e3)
  if (plot == "all") {
    O1plot <- function(th) {
      plot(th, O1(th), type = "l",
           xlab = "Variance Value",
           ylab = "maxLL - LL - logk",
           main = "Objective Function (O1 type)")
      abline(h = 0, col = "red")
      abline(v = v0, lty=2)
      legend("topright",
             legend = c(paste("PE = ", format(v0, digits = 2)), "Zero Line"),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    O2plot <- function(th) {
      plot(th, O2(th), type = "l",
           xlab = "Variance Value",
           ylab = "LL",
           main = "Log Likelihood Function (O2 type)")
      abline(h = maxLL, col = "blue")
      abline(v = v0, lty=2)
      abline(h = maxLL - logk, col = "red")
      legend("bottomright",
             legend = c(paste("PE = ", format(v0, digits = 2)),
                        paste("maxLL = ", format(maxLL, digits = 4)),
                        paste("maxLL-logk = ", format(maxLL - logk, digits = 4))),
             lty = c(2, 1, 1),
             col = c("black", "blue", "red"))
    }
    O3plot <- function(th) {
      plot(th, O3(th), type = "l",
           xlab = "Variance Value",
           ylab = "maxLL - LL",
           main = "Log LRT (O3 type)")
      abline(h = logk, col = "red")
      abline(v = v0, lty = 2)
      legend("topright",
             legend=c(paste("PE = ", format(v0, digits = 2)),
                      paste("logk = ", format(logk, digits = 4))),
             lty=c(2, 1),
             col=c("black", "red"))
    }
    par(mfrow = c(2,2))
    O1plot(dth); O2plot(dth); O3plot(dth)
    par(mfrow = c(1,1))
  } else if (plot == "OBJ" | plot == "O1" | plot == 1) {
    O1plot(dth)
  } else if (plot == "OFV" | plot == "O2" | plot == 2) {
    O2plot(dth)
  } else if (plot == "LRT" | plot == "O3" | plot == 3) {
    O3plot(dth)
  } else {}

  return(list(demo = demo, LI = LI, LI.sd = LI.sd, CI = CI, plot = plot))
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

qlipois = function(data, test.val, conf.level = 0.95, eps = 1e-08, k)
{
  x <- data[!is.na(data)]
  n <- length(x)

  if (!is.numeric(x)) stop("! Check the data input!")
  ifelse (n == 1, Lam0 <- x, Lam0 <- sum(x)/n)

  maxLL <- sum(x) * log(Lam0) - n * Lam0

  if (!missing(k)) {
    logk <- log(k)
  } else if (n == 1) {
    logk <- log(2/(1 - conf.level))
  } else {
    logk <- n/2 * log(1 + qf(conf.level, 1, n - 1)/(n - 1))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  LL <- function(lam, cutoff) ifelse(lam > 0, sum(x) * log(lam) - n * lam, 0)
  O1 <- function(lam, cutoff) maxLL - LL(lam, cutoff) - logk
  O2 <- function(lam, cutoff) LL(lam, cutoff)

  ifelse (Lam0 > 0,
          pLL <- uniroot(O1, c(eps, Lam0), cutoff = logk)$root, pLL <- 0)
  ifelse (!is.finite(maxLL),
          pUL <- Inf, pUL <- uniroot(O1, c(Lam0, 1e+09), cutoff = logk)$root)

  demo <- c("Poisson Mean" = Lam0, "Data Size" = n,
            "Conf. Level" = conf.level, "Testing Value" = test.val)
  interval <- c("LI PE" = Lam0,
                "LI lower" = pLL,
                "LI upper" = pUL,
                "LI width" = pUL-pLL)
  stat <- c("Cutoff Value k" = exp(logk),
            "Likelihood Ratio" = exp(O2(test.val))/exp(maxLL),
            "Testing Result" = ifelse(O1(test.val) < 0, TRUE, FALSE))
  verdict <- ifelse (O1(test.val) < 0,
                     "Testing value can be explained :: by LI method",
                     "! Testing value !CANNOT! be explained :: by LI method")

  dp <- seq(0, 5*Lam0, length.out = 1e3)
  plot(dp, O2(dp), type = "l",
       xlab = "Poisson Mean Value",
       ylab = "LL",
       main = "Log Likelihood Function (O2 type)")
  points(test.val, O2(test.val), col = "green4", cex = 1.5, pch = 16)
  abline(h = maxLL, col = "blue")
  abline(v = Lam0, lty = 3)
  abline(h = maxLL - logk, col = "red")
  abline(v = test.val, col = "green4", lty = 2)
  abline(h = O2(test.val), col = "green4")
  legend("bottomright",
         legend = c(paste("PE = ", format(Lam0, digits = 2)),
                    paste("maxLL = ", format(maxLL, digits = 4)),
                    paste("Cutoff = ", format(maxLL-logk, digits = 4)),
                    paste("Testing = ", format(test.val, digits = 4)),
                    paste("LL Testing = ", format(O2(test.val), digits = 4))),
         lty = c(3, 1, 1, 2, 1),
         col = c("black", "blue", "red", "green4", "green4"))

  return(list(demo = demo, interval = interval, stat = stat, verdict = verdict))
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

lir = function (num.data, denom.data, plot = "all", conf.level = 0.95, df = 2.4, k)
{
  x <- num.data[!is.na(num.data)]
  y <- denom.data[!is.na(denom.data)]
  n1 <- length(x)
  n2 <- length(y)

  if (!is.numeric(x) | sum(is.infinite(x) > 0) | sum(is.nan(x)) >
      0 | n1 < 3 | length(unique(x)) == 1)
    stop("Check the input!")
  if (!is.numeric(y) | sum(is.infinite(y) > 0) | sum(is.nan(y)) >
      0 | n2 < 3 | length(unique(y)) == 1)
    stop("Check the input!")

  n1v1 <- sum((x - mean(x))^2)
  n2v2 <- sum((y - mean(y))^2)
  v1 <- n1v1 / n1
  v2 <- n2v2 / n2
  v1c <- n1v1 / (n1 - 1)
  v2c <- n2v2 / (n2 - 1)
  R0 <- v1 / v2
  R0c <- v1c / v2c
  n0 <- n1 + n2

  if (!missing(k)) {
    logk <- log(k)
    } else {
      logk <- n0 / 2 * log(1 + qf(conf.level, 1, n0 - df)/(n0 - df))
      logk <- min(logk, log(2/(1 - conf.level)))
    }

  O2 <- function(r) {
    th <- (n1v1 + r * n2v2)/r/n0
    ln2pith <- log(2 * pi * th)
    -(n1 * (log(r) + ln2pith) + n1v1/r/th + n2 * ln2pith + n2v2/th)/2
  }
  maxLL <- -(n1 * (log(2 * pi * v1) + 1) + n2 * (log(2 * pi * v2) + 1))/2
  O1 <- function(r) maxLL - O2(r) - logk
  O3 <- function(r) maxLL - O2(r)

  varLL <- uniroot(O1, c(1e-08, R0))$root
  varUL <- uniroot(O1, c(R0, 1e+06))$root

  varLB <- R0c / qf(0.5 + conf.level/2, n1 - 1, n2 - 1)
  varUB <- R0c / qf(0.5 - conf.level/2, n1 - 1, n2 - 1)

  demo <- c("Num. Size" = n1, "Denom. Size" = n2,
            "Cutoff Value k" = exp(logk), "maxLL" = maxLL)
  LI <- c("Point Estimate" = R0, "lower" = varLL, "upper" = varUL,
          "width" = varUL - varLL)
  LI.sdR <- c("Point Estimate" = sqrt(R0), "lower" = sqrt(varLL),
              "upper" = sqrt(varUL))
  CI <- c("Point Estimate" = R0c, "lower" = varLB, "upper" = varUB,
          "width" = varUB - varLB)
  plot <- c("Current plot setting is" = plot)

  dr <- seq(varLL/2, varUL * 2, length.out = 1e3)
  if (plot == "all") {
    O1plot <- function(r) {
      plot(r, O1(r), type = "l",
           xlab = "Variance Ratio Value",
           ylab = "maxLL - LL - logk",
           main = "Objective Function (O1 type)")
      abline(h = 0, col = "red")
      abline(v = R0, lty=2)
      legend("topright",
             legend = c(paste("PE = ", format(R0, digits = 2)), "Zero Line"),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    O2plot <- function(r) {
      plot(r, O2(r), type = "l",
           xlab = "Variance Ratio Value",
           ylab = "LL",
           main = "Log Likelihood Function (O2 type)")
      abline(h = maxLL, col = "blue")
      abline(v = R0, lty=2)
      abline(h = maxLL - logk, col = "red")
      legend("bottomright",
             legend = c(paste("PE = ", format(R0, digits=2)),
                      paste("maxLL = ", format(maxLL, digits=4)),
                      paste("maxLL-logk = ", format(maxLL-logk, digits=4))),
             lty = c(2, 1, 1),
             col = c("black", "blue", "red"))
    }
    O3plot <- function(r) {
      plot(r, O3(r), type = "l",
           xlab = "Variance Ratio Value",
           ylab = "maxLL - LL",
           main = "Log LRT (O3 type)")
      abline(h = logk, col = "red")
      abline(v = R0, lty = 2)
      legend("topright",
             legend = c(paste("PE = ", format(R0, digits = 2)),
                        paste("logk = ", format(logk, digits = 4))),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    par(mfrow = c(2,2))
    O1plot(dr); O2plot(dr); O3plot(dr)
    par(mfrow = c(1,1))
  } else if (plot == "OBJ" | plot == "O1" | plot == 1) {
    O1plot(dr)
  } else if (plot == "OFV" | plot == "O2" | plot == 2) {
    O2plot(dr)
  } else if (plot == "LRT" | plot == "O3" | plot == 3) {
    O3plot(dr)
  } else {}

  return(list(demo = demo, LI = LI, LI.sdR = LI.sdR, CI = CI, plot = plot))
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

qliv = function (set.a, set.b, conf.level = 0.95, df = 2.4, k)
{
  dx <- set.a[!is.na(set.a)]
  dy <- set.b[!is.na(set.b)]
  dn1 <- length(dx)
  dn2 <- length(dy)

  if (dn1 <= dn2) {
    x <- dx
    y <- dy
    } else {
      y <- dx
      x <- dy
    }

  n1 <- length(x)
  n2 <- length(y)
  n1v1 <- sum((x - mean(x))^2)
  n2v2 <- sum((y - mean(y))^2)
  v1 <- n1v1/n1
  v2 <- n2v2/n2

  if (!is.numeric(x) | sum(is.infinite(x) > 0) | sum(is.nan(x)) >
      0 | n1 < 3 | length(unique(x)) == 1)
    stop("Check the input!")
  if (!is.numeric(y) | sum(is.infinite(y) > 0) | sum(is.nan(y)) >
      0 | n2 < 3 | length(unique(y)) == 1)
    stop("Check the input!")

  R0 <- v1/v2
  n0 <- n1 + n2
  maxLL <- -(n1 * (log(2 * pi * v1) + 1) + n2 * (log(2 * pi * v2) + 1))/2

  if (!missing(k)) {
    logk <- log(k)
    } else {
      logk <- n0/2 * log(1 + qf(conf.level, 1, n0 - df)/(n0 - df))
      logk <- min(logk, log(2/(1 - conf.level)))
    }

  O2 <- function(r) {
    th <- (n1v1 + r * n2v2) / r / n0
    ln2pith <- log(2 * pi * th)
    -(n1 * (log(r) + ln2pith) + n1v1 / r / th + n2 * ln2pith + n2v2 / th) / 2
  }

  O1 <- function(r) maxLL - O2(r) - logk

  varLL <- uniroot(O1, c(1e-08, R0))$root
  varUL <- uniroot(O1, c(R0, 1e+06))$root
  CI <- var.test(x, y, conf.level = conf.level)
  demo <- c("Size 1 (smaller)" = n1, "Size 2" = n2,
            "Conf. Level" = conf.level, "LI df" = df)
  interval <- c("LI PE" = R0,
                "LI lower" = varLL,
                "LI upper" = varUL,
                "LI width" = varUL-varLL,
                "CI PE" = unname(CI$estimate),
                "CI lower" = CI$conf.int[1],
                "CI upper" = CI$conf.int[2],
                "CI width" = CI$conf.int[2]-CI$conf.int[1])
  stat <- c("p-value" = CI$p.value,
            "Cutoff Value k" = exp(logk),
            "Likelihood Ratio" = exp(O2(1))/exp(maxLL),
            "HETEROscedasticity" = ifelse (O1(1) < 0, FALSE, TRUE))
  verdict <- ifelse (O1(1) < 0,
                     "Equal Variance :: by LI method",
                     "! INequivalent Variance :: by LI method")


  if (varUL * 2 < 1) {
    dr <- seq(varLL/2, 2, length.out = 1e3)
  } else if (1 < varLL/2) {
    dr <- seq(0.5, varUL * 2, length.out = 1e3)
  } else {dr <- seq(varLL/2, varUL * 2, length.out = 1e3)}

  plot(dr, O2(dr), type = "l",
       xlab = "Variance Ratio Value (Sample Size Allocated)",
       ylab = "LL",
       main = "Log Likelihood Function (O2 type)")
  points(1, O2(1), col = "green4", cex = 1.5, pch = 16)
  abline(h = maxLL, col = "blue")
  abline(v = R0, lty = 3)
  abline(h = maxLL - logk, col = "red")
  abline(v = 1, col = "green4", lty = 2)
  abline(h = O2(1), col = "green4")
  legend("bottom", horiz = TRUE, cex = 0.6,
         legend = c(paste("PE = ", format(R0, digits = 2)),
                    paste("maxLL = ", format(maxLL, digits = 4)),
                    paste("Cutoff = ", format(maxLL-logk, digits = 4)),
                    paste("LL Eq Var = ", format(O2(1), digits = 4))),
         lty = c(3, 1, 2, 1),
         col = c("black", "blue", "red", "green4"))

  return(list(demo = demo, interval = interval, stat = stat, verdict = verdict))
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

lib = function (event, total, plot = "all", conf.level = 0.95, eps = 1e-08, k)
{
  y <- event
  n <- total

  if (length(y) != 1 | length(n) != 1)
    stop("Event counts should be a sinlge natural number!")
  if (any(y < 0) | any(n < 0) | any(!is.finite(y)) | any(!is.finite(n)))
    stop("Check the event counts and(or) total counts!")
  if (!missing(k)) {
    logk <- log(k)
  } else if (n == 1) {
    logk <- log(2/(1 - conf.level))
  } else {
    logk <- n/2 * log(1 + qf(conf.level, 1, n - 1)/(n - 1))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  p0 <- y/n

  if (y == 0 | y == n) {
    LE <- logk/sqrt(n)
    maxLL <- 0
  } else {
    LE <- logk * sqrt(p0 * (1 - p0))
    maxLL <- y * log(p0) + (n - y) * log(1 - p0)
  }

  O1 <- function(p) {
    LL <- ifelse(p < 1e-300 | p > 1 - 1e-300, 0, y * log(p) +
                   (n - y) * log(1 - p))
    maxLL - LL - logk
  }
  O2 <- function(p) {
    ifelse(p < 1e-300 | p > 1 - 1e-300, 0, y * log(p) + (n - y) * log(1 - p))
  }
  O3 <- function(p) {
    LL <- ifelse(p < 1e-300 | p > 1 - 1e-300, 0, y * log(p) +
                  (n - y) * log(1 - p))
    maxLL - LL
  }

  if (p0 < eps) {
    bLL <- 0
  } else {
    rTemp <- try(uniroot(O1, c(max(eps, p0 - LE), p0 + eps)), silent = TRUE)
    if (!inherits(rTemp, "try-error")) {
      bLL <- rTemp$root
    } else {
      bLL <- max(p0 - LE, 0)
    }
  }

  if (p0 > 1 - eps) {
    bUL <- 1
  } else {
    rTemp = try(uniroot(O1, c(p0 - eps, min(p0 + LE, 1 - eps))), silent = TRUE)
    if (!inherits(rTemp, "try-error")) {
      bUL = rTemp$root
    } else {
      bUL <- min(p0 + LE, 1)
    }
  }

  CIb <- binom.test(y, n)

  demo <- c("Event Counts" = y, "Total Counts" = n,
            "Cutoff Value k" = exp(logk), "maxLL" = maxLL)
  LI <- c("Point Estimate" = p0, "lower" = bLL, "upper" = bUL,
          "width" = bUL - bLL)
  CI <- c("Point Estimate" = unname(CIb$estimate),
          "lower" = CIb$conf.int[1], "upper" = CIb$conf.int[2],
          "width" = CIb$conf.int[2] - CIb$conf.int[1])
  plot <- c("Current plot setting is" = plot)

  dp <- seq(0, 1, length.out = 1e3)
  if (plot == "all") {
    O1plot <- function(p) {
      plot(p, O1(p), type = "l",
           xlab = "Proportion Value",
           ylab = "maxLL - LL - logk",
           main = "Objective Function (O1 type)")
      abline(h = 0, col = "red")
      abline(v = p0, lty = 2)
      legend("topright",
             legend= c (paste("PE = ", format(p0, digits = 2)), "Zero Line"),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    O2plot <- function(p) {
      plot(p, O2(p), type = "l",
           xlab = "Proportion Value",
           ylab = "LL",
           main = "Log Likelihood Function (O2 type)")
      abline(h = maxLL, col = "blue")
      abline(v = p0, lty = 2)
      abline(h = maxLL - logk, col = "red")
      legend("bottomright",
             legend = c(paste("PE = ", format(p0, digits = 2)),
                        paste("maxLL = ", format(maxLL, digits = 4)),
                        paste("maxLL-logk = ", format(maxLL-logk, digits = 4))),
             lty = c(2, 1, 1),
             col = c("black", "blue", "red"))
    }
    O3plot <- function(p) {
      plot(p, O3(p), type = "l",
           xlab = "Proportion Value",
           ylab = "maxLL - LL",
           main = "Log LRT (O3 type)")
      abline(h = logk, col = "red")
      abline(v = p0, lty = 2)
      legend("topright",
             legend = c(paste("PE = ", format(p0, digits = 2)),
                        paste("logk = ", format(logk, digits = 4))),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    par(mfrow = c(2,2))
    O1plot(dp); O2plot(dp); O3plot(dp)
    par(mfrow = c(1,1))
  } else if (plot == "OBJ" | plot == "O1" | plot == 1) {
    O1plot(dp)
  } else if (plot == "OFV" | plot == "O2" | plot == 2) {
    O2plot(dp)
  } else if (plot == "LRT" | plot == "O3" | plot == 3) {
    O3plot(dp)
  } else {}

  return(list(demo = demo, LI = LI, CI = CI, plot = plot))
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

lim = function (data, plot = "all", conf.level = 0.95, df = 1, k)
{
  x <- data[!is.na(data)]
  n0 <- length(x)

  if (!is.numeric(x) | sum(is.infinite(x) > 0) | sum(is.nan(x)) > 0 | n0 < 3 |
      length(unique(x)) == 1) stop("Check the input!")

  m0 <- mean(x)

  if (!missing(k)) {
    logk <- log(k)
  } else {
    logk <- n0/2*log(1 + qf(conf.level, 1, n0 - df)/(n0 - df))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  LL <- function(th) -n0/2 * (log(2 * pi * sum((x - th)^2)/n0) + 1)
  maxLL <- sapply(m0, LL)

  O1 <- function(th) maxLL - sapply(th, LL) - logk
  O2 <- function(th) sapply(th, LL)
  O3 <- function(th) maxLL - sapply(th, LL)

  mLL <- uniroot(O1, c(-1e+08, m0), tol=1e-10)$root
  mUL <- uniroot(O1, c(m0, 1e+06), tol=1e-10)$root

  mLLc <- m0 - qt(0.5 + conf.level/2, n0 - 1) * sqrt(var(x)/n0)
  mULc <- m0 + qt(0.5 + conf.level/2, n0 - 1) * sqrt(var(x)/n0)

  demo <- c("Sample Size" = n0, "Cutoff Value k" = exp(logk), "maxLL" = maxLL)
  LI <- c("PE" = m0, "lower" = mLL, "upper" = mUL, "width" = mUL - mLL)
  CI <- c("PE" = m0, "lower" = mLLc, "upper" = mULc, "width" = mULc - mLLc)
  plot <- c("Current plot setting is" = plot)

  dm <- seq(mLL - 2, mUL + 2, length.out = 1e3)
  if (plot == "all") {
    O1plot <- function(th) {
      plot(th, O1(th), type = "l",
           xlab = "Mean Value",
           ylab = "maxLL - LL - logk",
           main = "Objective Function (O1 type)")
      abline(h = 0, col = "red")
      abline(v = m0, lty=2)
      legend("topright",
             legend = c(paste("PE = ", format(m0, digits = 2)), "Zero Line"),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    O2plot <- function(th) {
      plot(th, O2(th), type = "l",
           xlab = "Mean Value",
           ylab = "LL",
           main = "Log Likelihood Function (O2 type)")
      abline(h = maxLL, col = "blue")
      abline(v = m0, lty=2)
      abline(h = maxLL - logk, col = "red")
      legend("bottomright",
             legend = c(paste("PE = ", format(m0, digits = 2)),
                        paste("maxLL = ", format(maxLL, digits = 4)),
                        paste("maxLL-logk = ", format(maxLL - logk, digits = 4))),
             lty = c(2, 1, 1),
             col = c("black", "blue", "red"))
    }
    O3plot <- function(th) {
      plot(th, O3(th), type = "l",
           xlab = "Mean Value",
           ylab = "maxLL - LL",
           main = "Log LRT (O3 type)")
      abline(h = logk, col = "red")
      abline(v = m0, lty = 2)
      legend("topright",
             legend=c(paste("PE = ", format(m0, digits = 2)),
                      paste("logk = ", format(logk, digits = 4))),
             lty=c(2, 1),
             col=c("black", "red"))
    }
    par(mfrow = c(2,2))
    O1plot(dm); O2plot(dm); O3plot(dm)
    par(mfrow = c(1,1))
  } else if (plot == "OBJ" | plot == "O1" | plot == 1) {
    O1plot(dm)
  } else if (plot == "OFV" | plot == "O2" | plot == 2) {
    O2plot(dm)
  } else if (plot == "LRT" | plot == "O3" | plot == 3) {
    O3plot(dm)
  } else {}

  return(list(demo = demo, LI = LI, CI = CI, plot = plot))
}

#' @importFrom stats binom.test nlminb poisson.test qchisq qf qnorm qt t.test uniroot var var.test
#' @importFrom graphics abline legend par points
#' @export

lipois = function (event, unit.time = 1, data.size = 1,
                   plot = "all", conf.level = 0.95, eps = 1e-08, k)
{
  ifelse (length(event) == 1, Lam0 <- event/unit.time,
          "! Event count should be a natural number")

  ifelse (data.size == 1, n <- 1, n <- data.size)

  maxLL <- n * Lam0 * (log(Lam0) - 1)

  if (!missing(k)) {
    logk <- log(k)
  } else if (n == 1) {
    logk <- log(2/(1 - conf.level))
  } else {
    logk <- n/2 * log(1 + qf(conf.level, 1, n - 1)/(n - 1))
    logk <- min(logk, log(2/(1 - conf.level)))
  }

  O1 <- function(lam, cutoff) {
    LL <- ifelse(lam > 0, n * Lam0 * log(lam) - n * lam, 0)
    maxLL - LL - cutoff
  }
  O2 <- function(lam, cutoff) ifelse(lam > 0, n * Lam0 * log(lam) - n * lam, 0)
  O3 <- function(lam, cutoff) {
    LL <- ifelse(lam > 0, n * Lam0 * log(lam) - n * lam, 0)
    maxLL - LL
  }

  if (Lam0 > 0) {
    pLL <- uniroot(O1, c(eps, Lam0), cutoff = logk)$root
  } else {
    pLL <- 0
  }

  if (!is.finite(maxLL)) {
    pUL <- Inf
  } else {
    pUL <- uniroot(O1, c(Lam0, 1e+09), cutoff = logk)$root
  }

  CIp <- poisson.test(x = event, T = unit.time, conf.level = conf.level)
  demo <- c("Poisson Mean" = Lam0,
            "Data Size" = ifelse(data.size == 1, 1, data.size),
            "Cutoff Value k" = exp(logk), "maxLL" = maxLL)
  LI <- c("Point Estimate" = Lam0, "lower" = pLL, "upper" = pUL,
          "width" = pUL - pLL)
  CI <- c("Point Estimate" = unname(CIp$estimate),
          "lower" = CIp$conf.int[1], "upper" = CIp$conf.int[2],
          "width" = CIp$conf.int[2] - CIp$conf.int[1])
  plot <- c("Current plot setting is" = plot)

  dp <- seq(0, pUL + 2, length.out = 1e3)
  if (plot == "all") {
    O1plot <- function(p) {
      plot(p, O1(p, logk), type = "l",
           xlab = "Poisson Mean Value",
           ylab = "maxLL - LL - logk",
           main = "Objective Function (O1 type)")
      abline(h = 0, col = "red")
      abline(v = Lam0, lty=2)
      legend("topright",
             legend = c(paste("PE = ", format(Lam0, digits = 2)), "Zero Line"),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    O2plot <- function(p) {
      plot(p, O2(p, logk), type = "l",
           xlab = "Poisson Mean Value",
           ylab = "LL",
           main = "Log Likelihood Function (O2 type)")
      abline(h = maxLL, col = "blue")
      abline(v = Lam0, lty=2)
      abline(h = maxLL - logk, col = "red")
      legend("bottomright",
             legend=c(paste("PE = ", format(Lam0, digits = 2)),
                      paste("maxLL = ", format(maxLL, digits = 4)),
                      paste("maxLL-logk = ", format(maxLL-logk, digits = 4))),
             lty=c(2, 1, 1),
             col=c("black", "blue", "red"))
    }
    O3plot <- function(p) {
      plot(p, O3(p, logk), type = "l",
           xlab = "Poisson Mean Value",
           ylab = "maxLL - LL",
           main = "Log LRT (O3 type)")
      abline(h = logk, col = "red")
      abline(v = Lam0, lty = 2)
      legend("topright",
             legend = c(paste("PE = ", format(Lam0, digits = 2)),
                      paste("logk = ", format(logk, digits = 4))),
             lty = c(2, 1),
             col = c("black", "red"))
    }
    par(mfrow = c(2,2))
    O1plot(dp); O2plot(dp); O3plot(dp)
    par(mfrow = c(1,1))
  } else if (plot == "OBJ" | plot == "O1" | plot == 1) {
    O1plot(dp)
  } else if (plot == "OFV" | plot == "O2" | plot == 2) {
    O2plot(dp)
  } else if (plot == "LRT" | plot == "O3" | plot == 3) {
    O3plot(dp)
  } else {}

  return(list(demo = demo, LI = LI, CI = CI, plot = plot))
}

\name{liod}
\alias{liod}
\title{Likelihood Interval for Odds Ratio of 2-by-2 Contingency Table.}
\description{
  Likelihood interval for odds ratio of 2-by-2 contingency table. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended.
}
\arguments{
  \item{exposure.O_event.O}{a numeric vector of exposure (+) and event (+), 'a' of 2-by-2 table; mandatory}
  \item{exposure.O_TOTAL}{a numeric vector of exposure (+), 'a' + 'b' of 2-by-2 table; mandatory}
  \item{exposure.X_event.O}{a numeric vector of exposure (-) and event (-), 'c' of 2-by-2 table; mandatory}
  \item{exposure.X_TOTAL}{a numeric vector of exposure (-), 'c' + 'd' of 2-by-2 table; mandatory}
  \item{plot}{likelihood function plots by LI; default is "all". 'OBJ', 'O1', '1' is objective function plot; 'OFV', 'O2', '2' is log likelihood function plot; 'LRT', 'O3', '3' is log LRT function plot.}
  \item{conf.level}{confidence level for the interval estimation}
  \item{eps}{machine epsilon value; default is 1e-08}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{contin_2x2}{2-by-2 contingency table}
  \item{LI}{estimated interval of odds ratio by LI}
  \item{CI}{estimated interval of odds ratio by CI}
  \item{plot}{likelihood-related plots}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  liod(21, 43, 16, 67)
  liod(21, 43, 16, 67, plot = 0) # faster calculation
}

\name{qliv}
\alias{qliv}
\title{Testing Function for Variance Ratio of Two Samples from Normal Distribution}
\description{
  Testing function for variance ratio of two samples assuming normal distribution by LI method. O2 type likelihood function plot is also shown. Smaller sample is allocated to be in the nominator for more accurate and precise estimation.
}
\arguments{
  \item{set.a}{a numeric vector of data values; mandatory, pre-allocation}
  \item{set.b}{a numeric vector of data values; mandatory, pre-allocation}
  \item{conf.level}{confidence level for the interval estimation}
  \item{df}{degree of freedom for likelihood interval; default is 2.4}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{interval}{estimated interval by LI and CI.}
  \item{stat}{statistical values, such as p-value and likelihood ratio}
  \item{verdict}{estimation result as a sentence}
  \item{plot}{log likelihood function plot (O2 type)}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  x <- rnorm(30, 0, 1)
  y <- rnorm(20, 0, 1)
  qliv(x, y) # x placed in the denominator
}

\name{lir}
\alias{lir}
\title{Likelihood Interval for Variance Ratio of Two Samples from Normal Distribution}
\description{
  Likelihood interval for variance ratio of two samples assuming normal distribution. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended. Sample size is not allocated.
}
\arguments{
  \item{num.data}{a numeric vector of data values, variance value at the numerator position; mandatory}
  \item{denom.data}{a numeric vector of data values, variance value at the denominator position; mandatory}
  \item{plot}{likelihood function plots by LI; default is "all". 'OBJ', 'O1', '1' is objective function plot; 'OFV', 'O2', '2' is log likelihood function plot; 'LRT', 'O3', '3' is log LRT function plot.}
  \item{conf.level}{confidence level for the interval estimation}
  \item{df}{degree of freedom for likelihood interval; default is 2.4}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{LI}{estimated interval of variance ratio by LI}
  \item{LI.sdR}{estimated interval of standard deviation ratio by LI}
  \item{CI}{estimated interval of variance by CI}
  \item{plot}{likelihood-related plots}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  lir(rnorm(30, 0, 1), rnorm(20, 0, 1))
}

\name{qlim}
\alias{qlim}
\title{Testing Function for Mean Difference of Two Samples from Normal Distribution by LI Method}
\description{
  Testing function for mean difference of two samples assuming normal distribution by LI method. O2 type likelihood function plot is also shown. 
}
\arguments{
  \item{set.a}{a numeric vector of former data values; mandatory}
  \item{set.b}{a numeric vector of latter data values; mandatory}
  \item{conf.level}{confidence level for the interval estimation}
  \item{df}{degree of freedom for likelihood interval; default is 1}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{interval}{estimated interval by LI and CI. PE is mean(set.a) - mean(set.b).}
  \item{stat}{statistical values, such as p-value and likelihood ratio}
  \item{verdict}{estimation result as a sentence}
  \item{plot}{log likelihood function plot (O2 type)}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  x <- rnorm(30, 0, 1)
  y <- rnorm(20, 0, 1)
  qlim(x, y)
}

\name{lipois}
\alias{lipois}
\title{Likelihood Interval for Poisson Mean of Single Sample from Poisson Distribution}
\description{
  Likelihood interval for Poisson mean of single sample assuming Poisson distribution. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended.
}
\arguments{
  \item{event}{number of events; a numeric vector}
  \item{unit.time}{unit time for Poisson mean; default is 1}
  \item{data.size}{sample size. If not specified, size is assumed to be 1. For LI being more precise, sample size must be considered.}
  \item{conf.level}{confidence level for the interval estimation}
  \item{eps}{machine epsilon value; default is 1e-08}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{LI}{estimated interval of Poisson mean by LI}
  \item{CI}{estimated interval of Poisson mean by CI}
  \item{plot}{likelihood-related plots}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  lipois(8)
  lipois(event = 8, unit.time = 3)
  lipois(event = 8, unit.time = 3, data.size = 6)
}

\name{lim}
\alias{lim}
\title{Likelihood Interval for Mean of Single Sample from Normal Distribution}
\description{
  Likelihood interval for mean of single sample assuming normal distribution. Likelihood function plot is also shown. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended.
}
\arguments{
  \item{data}{a numeric vector of data values; mandatory}
  \item{plot}{likelihood function plots by LI; default is "all". 'OBJ', 'O1', '1' is objective function plot; 'OFV', 'O2', '2' is log likelihood function plot; 'LRT', 'O3', '3' is log LRT function plot.}
  \item{conf.level}{confidence level for the interval estimation}
  \item{df}{degree of freedom for likelihood interval; default is 1}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{LI}{estimated interval of mean by LI}
  \item{CI}{estimated interval of mean by CI}
  \item{plot}{likelihood-related plots}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  lim(rnorm(20, 0, 1))
}

\name{inteli-package}
\alias{inteli-package}
\alias{inteli}
\docType{package}
\title{Interval Estimation by Likelihood Method}
\description{
Parameter estimation via likelihood interval (LI) compared to conventional method (CI).
}
\details{
  Currently used CI method has its limitation when the test statistics are asymmetrical (chi-square test, F-test) or the model functions are non-linear. It can be overcome by using the likelihood functions for the interval estimation. 'inteli' package now supports interval estimation for the mean, variance, variance ratio, binomial distribution, Poisson distribution, odds ratio, risk difference, relative risk and their likelihood function plots. Testing functions are also provided.
}
\author{
\strong{Maintainer}: Minkyu Kim \email{mkim@acr.kr}

Authors:
\itemize{
  \item Kyun-Seop Bae \email{k@acr.kr} (\href{https://orcid.org/0000-0001-7399-5879}{ORCID})
  \item Minkyu Kim \email{mkim@acr.kr}
}
}
\references{
\enumerate{
\item Wilks SS. The Large-sample Distribution of the Likelihood Ratio for Testing Composite Hypotheses. Ann Math Stat. 1938;9(1):60-62.
\item Edwards AWF. Likelihood. 1972.
\item Fisher RA. Statistical Methods and Scientific Inference. 3e. 1973.
\item Bates DM, Watts DG. Nonlinear Regression Analysis and its Application. 1988.
\item Ruppert D, Cressie N, Carroll RJ. A Transformation/Weighting Model for Estimating Michaelis-Menten Parameters. Cornell University Technical Report 796. 1988.
\item Royall R. Statistical Evidence. 1997.
\item Pinheiro JC, Bates DM. Mixed Effects Models in S and S-PLUS. 2000.
\item Pawitan Y. In All Likelihood: Statistical Modelling and Inference Using Likelihood. 2001.
\item Lehmann EL. Fisher, Nayman, and the Creation of Classical Statistics. 2011.
\item Rohde CA. Introductory Statistical Inference with the Likelihood Function. 2014.
\item Held L, Bove DS. Likelihood and Bayesian Inference. 2020.
\item Lee MH, Bae KS. Likelihood interval for nonlinear regression. 2023.
}
}

\name{lib}
\alias{lib}
\title{Likelihood Interval for Probability of Single Sample from Binomial Distribution}
\description{
  Likelihood interval for probability of single sample assuming binomial distribution. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended.
}
\arguments{
  \item{event}{number of events from observed data; a numeric vector}
  \item{total}{total number of trials from observed data; a numeric vector}
  \item{plot}{likelihood function plots by LI; default is "all"}
  \item{conf.level}{confidence level for the interval estimation}
  \item{eps}{machine epsilon value; default is 1e-08}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{LI}{estimated interval of probability (y/n) by LI}
  \item{CI}{estimated interval of probability (y/n) by CI}
  \item{plot}{likelihood-related plots}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  lib(8, 10)
}

\name{liv}
\alias{liv}
\title{Likelihood Interval for Variance of Single Sample from Normal Distribution}
\description{
  Likelihood interval for variance of single sample assuming normal distribution. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended.
}
\arguments{
  \item{data}{a numeric vector of data values; mandatory}
  \item{plot}{likelihood function plots by LI; default is "all". 'OBJ', 'O1', '1' is objective function plot; 'OFV', 'O2', '2' is log likelihood function plot; 'LRT', 'O3', '3' is log LRT function plot.}
  \item{conf.level}{confidence level for the interval estimation}
  \item{df}{degree of freedom for likelihood interval; default is 1.2}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{LI}{estimated interval of variance by LI}
  \item{LI.sd}{estimated interval of standard deviation by LI}
  \item{CI}{estimated interval of variance by CI}
  \item{plot}{likelihood-related plots}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  liv(rnorm(30, 0, 1))
}

\name{qlib}
\alias{qlib}
\title{Testing Function for Probability from Binomial Distribution}
\description{
  Testing function for variance ratio of two samples assuming normal distribution by LI method. O2 type likelihood function plot is also shown.
}
\arguments{
  \item{event}{number of events from observed data; a numeric vector}
  \item{total}{total number of trials from observed data; a numeric vector}
  \item{test.val}{a numeric vector of testing value for probability}
  \item{conf.level}{confidence level for the interval estimation}
  \item{eps}{machine epsilon value; default is 1e-08}
  \item{k}{cutoff value for likelihood interval. If not specified, F-test is used.}
}
\value{
  \item{demo}{basic demographics of data}
  \item{interval}{estimated interval by LI and CI.}
  \item{stat}{statistical values, such as p-value and likelihood ratio}
  \item{verdict}{estimation result as a sentence}
  \item{plot}{log likelihood function plot (O2 type)}
}
\author{Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>}
\examples{
  qlib(8, 13, 0.7)
  qlib(3, 10, 0.8)
}
